audobject.define
================

.. automodule:: audobject.define


SignatureMismatchWarnLevel
--------------------------

.. autoclass:: SignatureMismatchWarnLevel
    :members:
    :undoc-members:
